@@ -24,8 +24,6 @@
 
 #include <Plasma/Containment>
 
-#include <gst/gst.h>
-
 #include "kscreeninterface.h"
 #include "screenshotinterface.h"
 
@@ -33,7 +31,7 @@ class PhonePanel : public Plasma::Containment
 {
     Q_OBJECT
     Q_PROPERTY(bool autoRotateEnabled READ autoRotate WRITE setAutoRotate NOTIFY autoRotateChanged);
-
+    Q_PROPERTY(bool torchEnabled READ torchEnabled NOTIFY torchChanged);
 public:
     PhonePanel( QObject *parent, const QVariantList &args );
     ~PhonePanel() override;
@@ -45,14 +43,14 @@ public Q_SLOTS:
 
     bool autoRotate();
     void setAutoRotate(bool value);
+    
+    bool torchEnabled() const;
 
 signals:
     void autoRotateChanged(bool value);
+    void torchChanged(bool value);
 
 private:
-    GstElement* m_pipeline;
-    GstElement* m_sink;
-    GstElement* m_source;
     bool m_running = false;
 
     org::kde::KScreen *m_kscreenInterface;
